Introduction into Graphical User Interfaces
*******************************************

This package provides an abstract interface for working with graphical user interfaces. If you want to develop tests
for different kinds of visual interfaces you can use this package to write your tests.

You can find different further packages that relies on this package like:

* ``balderhub-html``
* ``balderhub-textual`` (COMING SOON)

This package provides different kind of mixins, that can be used to define your own components include buttons,
checkboxes, radio buttons, text fields, labels, dropdowns, sliders, progress bars, tables, trees, menus, toolbars,
dialog boxes, tabs, and scrollbars, each serving specific interaction purposes.

You can control these element by using  `a balder guicontrol package <https://hub.balder.dev/guicontrol/>`_ .
Currently the following packages are supported:

* ``balderhub-selenium``
* ``balderhub-playwright`` (COMING SOON)
* ``balderhub-textual`` (COMING SOON)
